@@ -23,9 +23,24 @@ from . import errors as errors_
 from .class_validators import Validator, make_generic_validator
 from .error_wrappers import ErrorWrapper
 from .types import Json, JsonWrapper
-from .utils import AnyCallable, AnyType, Callable, ForwardRef, display_as_type, lenient_issubclass, sequence_like
+from .utils import (
+    AnyCallable,
+    AnyType,
+    Callable,
+    ForwardRef,
+    display_as_type,
+    is_literal_type,
+    lenient_issubclass,
+    literal_values,
+    sequence_like,
+)
 from .validators import NoneType, constant_validator, dict_validator, find_validators
 
+try:
+    from typing_extensions import Literal
+except ImportError:
+    Literal = None  # type: ignore
+
 Required: Any = Ellipsis
 
 if TYPE_CHECKING:  # pragma: no cover
@@ -46,7 +61,8 @@ class Shape(IntEnum):
     SET = 3
     MAPPING = 4
     TUPLE = 5
-    SEQUENCE = 6
+    TUPLE_ELLIPS = 6
+    SEQUENCE = 7
 
 
 class Field:
@@ -161,8 +177,8 @@ class Field:
             # user will need to call model.update_forward_refs()
             return
 
-        self.validate_always: bool = (
-            getattr(self.type_, 'validate_always', False) or any(v.always for v in self.class_validators.values())
+        self.validate_always = getattr(self.type_, 'validate_always', False) or any(
+            v.always for v in self.class_validators.values()
         )
 
         if not self.required and self.default is None:
@@ -180,6 +196,12 @@ class Field:
         if self.type_ is Pattern:
             # python 3.7 only, Pattern is a typing object but without sub fields
             return
+        if is_literal_type(self.type_):
+            values = literal_values(self.type_)
+            if len(values) > 1:
+                self.type_ = Union[tuple(Literal[value] for value in values)]
+            else:
+                return
         origin = getattr(self.type_, '__origin__', None)
         if origin is None:
             # field is not "typing" object eg. Union, Dict, List etc.
@@ -198,12 +220,26 @@ class Field:
 
         if issubclass(origin, Tuple):  # type: ignore
             self.shape = Shape.TUPLE
-            self.sub_fields = [
-                self._create_sub_type(t, f'{self.name}_{i}') for i, t in enumerate(self.type_.__args__)  # type: ignore
-            ]
+            self.sub_fields = []
+            for i, t in enumerate(self.type_.__args__):  # type: ignore
+                if t is Ellipsis:
+                    self.type_ = self.type_.__args__[0]  # type: ignore
+                    self.shape = Shape.TUPLE_ELLIPS
+                    return
+                self.sub_fields.append(self._create_sub_type(t, f'{self.name}_{i}'))
             return
 
         if issubclass(origin, List):
+            # Create self validators
+            get_validators = getattr(self.type_, '__get_validators__', None)
+            if get_validators:
+                self.class_validators.update(
+                    {
+                        f'list_{i}': Validator(validator, whole=True, pre=True, always=True, check_fields=False)
+                        for i, validator in enumerate(get_validators())
+                    }
+                )
+
             self.type_ = self.type_.__args__[0]  # type: ignore
             self.shape = Shape.LIST
         elif issubclass(origin, Set):
@@ -244,11 +280,7 @@ class Field:
                     )
             v_funcs = (
                 *[v.func for v in class_validators_ if not v.whole and v.pre],
-                *(
-                    get_validators()
-                    if get_validators
-                    else find_validators(self.type_, self.model_config.arbitrary_types_allowed)
-                ),
+                *(get_validators() if get_validators else list(find_validators(self.type_, self.model_config))),
                 self.schema is not None and self.schema.const and constant_validator,
                 *[v.func for v in class_validators_ if not v.whole and not v.pre],
             )
@@ -295,7 +327,7 @@ class Field:
             v, errors = self._apply_validators(v, values, loc, cls, self.whole_post_validators)
         return v, errors
 
-    def _validate_json(self, v: str, loc: Tuple[str, ...]) -> Tuple[Optional[Any], Optional[ErrorWrapper]]:
+    def _validate_json(self, v: Any, loc: Tuple[str, ...]) -> Tuple[Optional[Any], Optional[ErrorWrapper]]:
         try:
             return Json.validate(v), None
         except (ValueError, TypeError) as exc:
@@ -307,7 +339,6 @@ class Field:
         """
         Validate sequence-like containers: lists, tuples, sets and generators
         """
-
         if not sequence_like(v):
             e: errors_.PydanticTypeError
             if self.shape is Shape.LIST:
@@ -335,6 +366,8 @@ class Field:
 
         if self.shape is Shape.SET:
             converted = set(result)
+        elif self.shape is Shape.TUPLE_ELLIPS:
+            converted = tuple(result)
         elif self.shape is Shape.SEQUENCE:
             if isinstance(v, tuple):
                 converted = tuple(result)
